==> widestudio-3.80.1_FreeBSD4.10R.tgz: ws/include/WSCroot.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef	WSCROOT_H
#define	WSCROOT_H

#define WSMFclassInit(CN, VC) \
  char* CN::getThisClassName(){return(#CN);} \
  char* CN::getClassName(){return(#CN);} \
  void* CN::cast(char* class_name){ \
    if( class_name == NULL ){  \
      return(this); \
    }else if(!strcmp(class_name,#CN)){ \
      return(this); \
    }else{ \
      return(VC::cast(class_name)); \
    } \
  }

#define	WSMFclassDef(CN,VC) \
  public:                   \
  char* getThisClassName(); \
  virtual char* getClassName(); \
  virtual void* cast(char *cname = NULL)

class WSCroot{

public:
	WSCroot();
	virtual	~WSCroot();
	virtual	char* getClassName();
	virtual	void* cast(char* cname = NULL);
} ;

#endif

==> widestudio-3.80.5_FreeBSD4.10R.tgz: ws/include/WSCroot.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef	WSCROOT_H
#define	WSCROOT_H

#define WSMFclassInit(CN, VC) \
  char* CN::getThisClassName(){return(#CN);} \
  char* CN::getClassName(){return(#CN);} \
  void* CN::cast(char* class_name){ \
    if( class_name == NULL ){  \
      return(this); \
    }else if(!strcmp(class_name,#CN)){ \
      return(this); \
    }else{ \
      return(VC::cast(class_name)); \
    } \
  }

#define	WSMFclassDef(CN,VC) \
  public:                   \
  WSDLEX32 char* getThisClassName(); \
  WSDLEX32 virtual char* getClassName(); \
  WSDLEX32 virtual void* cast(char *cname = NULL)

class WSCroot{

public :
	WSDLEX32 WSCroot();
	WSDLEX32 virtual	~WSCroot();
	WSDLEX32 virtual	char* getClassName();
	WSDLEX32 virtual	void* cast(char* cname = NULL);
} ;

#endif
